SpidermiRanalyze_Community_detection: Find community detection
Description
SpidermiRanalyze_Community_detection try to find dense subgraphs in directed or undirected graphs, by optimizing some criteria.
Usage
SpidermiRanalyze_Community_detection(data, type)
Arguments
data
SpidermiRanalyze_mirna_network output or SpidermiRanalyze_mirna_gene_complnet
type
with the parameter type the user can choose the algorithm to calculate the community structure
EB edge.betweenness.community
FC fastgreedy.community
WC walktrap.community
SC spinglass.community
LE leading.eigenvector.community
LP label.propagation.community