Learn R Programming

SpidermiR (version 1.1.8)

SpidermiRanalyze_Community_detection_net: Find the network of community detection and direct biormarker

Description

SpidermiRanalyze_direct_net find the direct interactions from a specific community

Usage

SpidermiRanalyze_Community_detection_net(data, comm_det, size)

Arguments

data
SpidermiRanalyze_mirna_network output or SpidermiRanalyze_mirna_gene_complnet
comm_det
SpidermiRanalyze_Community_detection
size
the index of community detection obtained from SpidermiRanalyze_Community_detection

Value

dataframe with the interatcions

Examples

Run this code
miRNA_cN <-data.frame(gA=c('hsa-let-7a','hsa-miR-300'),gB=c('FOXM1','KPNA4'),stringsAsFactors=FALSE)
comm<-  SpidermiRanalyze_Community_detection(data=miRNA_cN,type="FC") 
cd_net<-SpidermiRanalyze_Community_detection_net(data=miRNA_cN,comm_det=comm,size=1)

Run the code above in your browser using DataLab