Learn R Programming

SpidermiR (version 1.1.8)

SpidermiRanalyze_direct_subnetwork: Searching by biomarkers of interest with direct interaction by ONLY the nodes in BI

Description

SpidermiRanalyze_direct_subnetwork creates a sub network composed by ONLY the nodes in genes of interest and the edges between them

Usage

SpidermiRanalyze_direct_subnetwork(data, BI)

Arguments

data
SpidermiRanalyze_mirna_network output or SpidermiRanalyze_mirna_gene_complnet
BI
a set of biomarkers of interest

Value

dataframe with direct interaction of biomarkers of interest

Examples

Run this code
miRNA_cN <-data.frame(gA=c('hsa-let-7a','FOXM1'),gB=c('FOXM1','KPNA4'),stringsAsFactors=FALSE)
biomark_of_interest<-c("hsa-let-7a","CDK","FOXO1","hsa-miR-27a")
subnet<-SpidermiRanalyze_direct_subnetwork(data=miRNA_cN,BI=biomark_of_interest)

Run the code above in your browser using DataLab