Learn R Programming

SpidermiR (version 1.1.8)

SpidermiRquery_spec_networks: Searching by network categories

Description

The user can visualize the database or reference where the information came from

Usage

SpidermiRquery_spec_networks(organismID, network)

Arguments

organismID
describes index of a specific specie obtained by SpidermiRquery_species output
network
The network type the user is interested in. Example:
COexp
Co-expression
PHint
Physical_interactions
COloc
Co-localization
GENint
Genetic_interactions
PATH
Pathway
SHpd
Shared_protein_domains

Value

a list of the database or reference where the information came from.

Examples

Run this code
org<-SpidermiRquery_species(species)
net_shar_prot<-SpidermiRquery_spec_networks(organismID = org[9,],
                                        network = "SHpd")
                                        
                                        

Run the code above in your browser using DataLab